==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/costexplorer/kotlin/inputs/GetTagsFilterAndDimension.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.costexplorer.kotlin.inputs

import com.pulumi.aws.costexplorer.inputs.GetTagsFilterAndDimension.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property key Unique name of the Cost Category.
 * @property matchOptions Match options that you can use to filter your results. MatchOptions is only applicable for actions related to cost category. The default values for MatchOptions is `EQUALS` and `CASE_SENSITIVE`. Valid values are: `EQUALS`,  `ABSENT`, `STARTS_WITH`, `ENDS_WITH`, `CONTAINS`, `CASE_SENSITIVE`, `CASE_INSENSITIVE`.
 * @property values Specific value of the Cost Category.
 */
public data class GetTagsFilterAndDimension(
    public val key: String? = null,
    public val matchOptions: List<String>? = null,
    public val values: List<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.costexplorer.inputs.GetTagsFilterAndDimension> {
    override fun toJava(): com.pulumi.aws.costexplorer.inputs.GetTagsFilterAndDimension =
        com.pulumi.aws.costexplorer.inputs.GetTagsFilterAndDimension.builder()
            .key(key?.let({ args0 -> args0 }))
            .matchOptions(matchOptions?.let({ args0 -> args0.map({ args0 -> args0 }) }))
            .values(values?.let({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [GetTagsFilterAndDimension].
 */
@PulumiTagMarker
public class GetTagsFilterAndDimensionBuilder internal constructor() {
    private var key: String? = null

    private var matchOptions: List<String>? = null

    private var values: List<String>? = null

    /**
     * @param value Unique name of the Cost Category.
     */
    @JvmName("awejuvgjwsnlcnmt")
    public suspend fun key(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.key = mapped
    }

    /**
     * @param value Match options that you can use to filter your results. MatchOptions is only applicable for actions related to cost category. The default values for MatchOptions is `EQUALS` and `CASE_SENSITIVE`. Valid values are: `EQUALS`,  `ABSENT`, `STARTS_WITH`, `ENDS_WITH`, `CONTAINS`, `CASE_SENSITIVE`, `CASE_INSENSITIVE`.
     */
    @JvmName("iehodoffyyvyivao")
    public suspend fun matchOptions(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.matchOptions = mapped
    }

    /**
     * @param values Match options that you can use to filter your results. MatchOptions is only applicable for actions related to cost category. The default values for MatchOptions is `EQUALS` and `CASE_SENSITIVE`. Valid values are: `EQUALS`,  `ABSENT`, `STARTS_WITH`, `ENDS_WITH`, `CONTAINS`, `CASE_SENSITIVE`, `CASE_INSENSITIVE`.
     */
    @JvmName("plwbmvyvntufkuia")
    public suspend fun matchOptions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.matchOptions = mapped
    }

    /**
     * @param value Specific value of the Cost Category.
     */
    @JvmName("awnrssgkwxjmbirh")
    public suspend fun values(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.values = mapped
    }

    /**
     * @param values Specific value of the Cost Category.
     */
    @JvmName("rracsxojbsinmuow")
    public suspend fun values(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.values = mapped
    }

    internal fun build(): GetTagsFilterAndDimension = GetTagsFilterAndDimension(
        key = key,
        matchOptions = matchOptions,
        values = values,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/costexplorer/kotlin/inputs/GetTagsFilterAndDimension.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.costexplorer.kotlin.inputs

import com.pulumi.aws.costexplorer.inputs.GetTagsFilterAndDimension.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property key Unique name of the Cost Category.
 * @property matchOptions Match options that you can use to filter your results. MatchOptions is only applicable for actions related to cost category. The default values for MatchOptions is `EQUALS` and `CASE_SENSITIVE`. Valid values are: `EQUALS`,  `ABSENT`, `STARTS_WITH`, `ENDS_WITH`, `CONTAINS`, `CASE_SENSITIVE`, `CASE_INSENSITIVE`.
 * @property values Specific value of the Cost Category.
 */
public data class GetTagsFilterAndDimension(
    public val key: String? = null,
    public val matchOptions: List<String>? = null,
    public val values: List<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.costexplorer.inputs.GetTagsFilterAndDimension> {
    override fun toJava(): com.pulumi.aws.costexplorer.inputs.GetTagsFilterAndDimension =
        com.pulumi.aws.costexplorer.inputs.GetTagsFilterAndDimension.builder()
            .key(key?.let({ args0 -> args0 }))
            .matchOptions(matchOptions?.let({ args0 -> args0.map({ args0 -> args0 }) }))
            .values(values?.let({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [GetTagsFilterAndDimension].
 */
@PulumiTagMarker
public class GetTagsFilterAndDimensionBuilder internal constructor() {
    private var key: String? = null

    private var matchOptions: List<String>? = null

    private var values: List<String>? = null

    /**
     * @param value Unique name of the Cost Category.
     */
    @JvmName("apvjtuwsesrablhn")
    public suspend fun key(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.key = mapped
    }

    /**
     * @param value Match options that you can use to filter your results. MatchOptions is only applicable for actions related to cost category. The default values for MatchOptions is `EQUALS` and `CASE_SENSITIVE`. Valid values are: `EQUALS`,  `ABSENT`, `STARTS_WITH`, `ENDS_WITH`, `CONTAINS`, `CASE_SENSITIVE`, `CASE_INSENSITIVE`.
     */
    @JvmName("cgaxrtucyrrnqura")
    public suspend fun matchOptions(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.matchOptions = mapped
    }

    /**
     * @param values Match options that you can use to filter your results. MatchOptions is only applicable for actions related to cost category. The default values for MatchOptions is `EQUALS` and `CASE_SENSITIVE`. Valid values are: `EQUALS`,  `ABSENT`, `STARTS_WITH`, `ENDS_WITH`, `CONTAINS`, `CASE_SENSITIVE`, `CASE_INSENSITIVE`.
     */
    @JvmName("eatlrnrqwnexwgmx")
    public suspend fun matchOptions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.matchOptions = mapped
    }

    /**
     * @param value Specific value of the Cost Category.
     */
    @JvmName("ggooebqmfkubpctj")
    public suspend fun values(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.values = mapped
    }

    /**
     * @param values Specific value of the Cost Category.
     */
    @JvmName("iwibsuwrcxumhcdk")
    public suspend fun values(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.values = mapped
    }

    internal fun build(): GetTagsFilterAndDimension = GetTagsFilterAndDimension(
        key = key,
        matchOptions = matchOptions,
        values = values,
    )
}
